==> nextcloud-24.0.9.tgz: nextcloud/apps/systemtags/l10n/sc.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Su nùmene de s'eticheta est bòidu",
    "Update" : "Agiorna",
    "Create" : "Crea",
    "Select tag …" : "Seletziona eticheta ...",
    "System tag %1$s added by the system" : "Eticheta de sistema %1$s agiunta dae su sistema",
    "Added system tag {systemtag}" : "Agiunta s'eticheta de sistema {systemtag}",
    "Added system tag %1$s" : "Agiunta s'eticheta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$sat agiuntu s'eticheta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} at agiuntu s'eticheta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Eticheta de sistema %1$s bogada dae su sistema",
    "Removed system tag {systemtag}" : "Bogada s'eticheta de sistema {systemtag}",
    "Removed system tag %1$s" : "Bogada s'eticheta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$snch'at bogadu s'eticheta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} nch'at bogadu s'eticheta de sistema {systemtag}",
    "You created system tag %1$s" : "As creadu s'eticheta de sistema %1$s",
    "You created system tag {systemtag}" : "As creadu s'eticheta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s at creadu s'eticheta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} at creadu s'eticheta de sistema {systemtag}",
    "You deleted system tag %1$s" : "As cantzelladu s'eticheta de sistema %1$s",
    "You deleted system tag {systemtag}" : "As cantzelladu s'eticheta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s at cantzelladu s'eticheta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} at cantzelladu s'eticheta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "As agiornadu s'eticheta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "As agiornadu s'eticheta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$sat agiornadu s'eticheta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} at agiornadu s'eticheta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "S'eticheta de sistema %2$s est istada agiunta in %1$s dae su sistema",
    "System tag {systemtag} was added to {file} by the system" : "S'eticheta de sistema {systemtag} est istada agiunta a {file} dae su sistema",
    "You added system tag %2$s to %1$s" : "As agiuntu s'eticheta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "As agiuntu s'eticheta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s at agiuntu s'eticheta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} at agiuntu s'eticheta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "S'eticheta de sistema %2$s est istada bogada dae %1$s dae su sistema",
    "System tag {systemtag} was removed from {file} by the system" : "S'eticheta de sistema {systemtag} est istada bogada dae {file} dae su sistema",
    "You removed system tag %2$s from %1$s" : "Nch'as bogadu s'eticheta de sistema %2$s dae %1$s",
    "You removed system tag {systemtag} from {file}" : "Nch'as bogadu s'eticheta de sistema {systemtag} dae {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s nch'at bogadu s'eticheta de sistema %3$s dae%2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} nch'at bogadu s'eticheta de sistema {systemtag} dae {file}",
    "%s (restricted)" : "%s (limitadu)",
    "%s (invisible)" : "%s (invisìbile)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Etichetas de sistema</strong> pro un'archìviu sunt istada modificadas",
    "Tags" : "Etichetas",
    "Collaborative tags" : "Etichetas collaborativas",
    "Collaborative tagging functionality which shares tags among users." : "Funtzione de etichetas collaborativas chi cumpartzit etichetas tra is utentes.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funtzione de etichetas collaborativas chi cumpartzit etichetas tra is utentes. Bellu meda pro is grupos.\n\t(Si ses unu frunidore cun un'installatzione de multi-tenancy, est cussigiadu a disativare cust'aplicatzione cando is etichetas sunt cumpartzidas).",
    "Tagged files" : "Archìvios cun eticheta",
    "Select tags to filter by" : "Seletziona etichetas pro filtrare",
    "No tags found" : "Peruna eticheta agatada",
    "Please select tags to filter by" : "Seletziona etichetas pro filtrare",
    "No files found for the selected tags" : "Perunu archìviu agatadu pro is etichetas seletzionadas",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Is etichetas collaborativas sunt a disponimentu pro totu is utentes. Is etichetas limitadas podent èssere bidas dae is utentes, chi però no ddas podent assignare. Is etichetas visìbiles sunt pro un'impreu de intro, ca is utentes no ddas podent nen bìdere nen assignare.",
    "Create a new tag" : "Crea un'eticheta noa",
    "Name" : "Nùmene",
    "Public" : "Pùblicu",
    "Restricted" : "Limitadu",
    "Invisible" : "Invisìbile",
    "Delete" : "Cantzella",
    "Reset" : "Torra a impostare",
    "No files in here" : "Perunu archìviu",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Size" : "Mannària",
    "Modified" : "Modificadu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.10.tgz: nextcloud/apps/systemtags/l10n/sc.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Eticheta de sistema %1$s agiunta dae su sistema",
    "Added system tag {systemtag}" : "Agiunta s'eticheta de sistema {systemtag}",
    "Added system tag %1$s" : "Agiunta s'eticheta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$sat agiuntu s'eticheta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} at agiuntu s'eticheta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Eticheta de sistema %1$s bogada dae su sistema",
    "Removed system tag {systemtag}" : "Bogada s'eticheta de sistema {systemtag}",
    "Removed system tag %1$s" : "Bogada s'eticheta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$snch'at bogadu s'eticheta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} nch'at bogadu s'eticheta de sistema {systemtag}",
    "You created system tag %1$s" : "As creadu s'eticheta de sistema %1$s",
    "You created system tag {systemtag}" : "As creadu s'eticheta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s at creadu s'eticheta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} at creadu s'eticheta de sistema {systemtag}",
    "You deleted system tag %1$s" : "As cantzelladu s'eticheta de sistema %1$s",
    "You deleted system tag {systemtag}" : "As cantzelladu s'eticheta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s at cantzelladu s'eticheta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} at cantzelladu s'eticheta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "As agiornadu s'eticheta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "As agiornadu s'eticheta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$sat agiornadu s'eticheta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} at agiornadu s'eticheta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "S'eticheta de sistema %2$s est istada agiunta in %1$s dae su sistema",
    "System tag {systemtag} was added to {file} by the system" : "S'eticheta de sistema {systemtag} est istada agiunta a {file} dae su sistema",
    "You added system tag %2$s to %1$s" : "As agiuntu s'eticheta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "As agiuntu s'eticheta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s at agiuntu s'eticheta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} at agiuntu s'eticheta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "S'eticheta de sistema %2$s est istada bogada dae %1$s dae su sistema",
    "System tag {systemtag} was removed from {file} by the system" : "S'eticheta de sistema {systemtag} est istada bogada dae {file} dae su sistema",
    "You removed system tag %2$s from %1$s" : "Nch'as bogadu s'eticheta de sistema %2$s dae %1$s",
    "You removed system tag {systemtag} from {file}" : "Nch'as bogadu s'eticheta de sistema {systemtag} dae {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s nch'at bogadu s'eticheta de sistema %3$s dae%2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} nch'at bogadu s'eticheta de sistema {systemtag} dae {file}",
    "%s (restricted)" : "%s (limitadu)",
    "%s (invisible)" : "%s (invisìbile)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Etichetas de sistema</strong> pro un'archìviu sunt istada modificadas",
    "Tags" : "Etichetas",
    "Collaborative tags" : "Etichetas collaborativas",
    "Collaborative tagging functionality which shares tags among users." : "Funtzione de etichetas collaborativas chi cumpartzit etichetas tra is utentes.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funtzione de etichetas collaborativas chi cumpartzit etichetas tra is utentes. Bellu meda pro is grupos.\n\t(Si ses unu frunidore cun un'installatzione de multi-tenancy, est cussigiadu a disativare cust'aplicatzione cando is etichetas sunt cumpartzidas).",
    "Create" : "Crea",
    "Update" : "Agiorna",
    "Delete" : "Cantzella",
    "Reset" : "Torra a impostare",
    "Loading …" : "Carrigamentu …",
    "Public" : "Pùblicu",
    "Restricted" : "Limitadu",
    "Invisible" : "Invisìbile",
    "Failed to load tags" : "No at fatu a carrigare is etichetas",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Is etichetas collaborativas sunt a disponimentu pro totu is utentes. Is etichetas limitadas podent èssere bidas dae is utentes, chi però no ddas podent assignare. Is etichetas visìbiles sunt pro un'impreu de intro, ca is utentes no ddas podent nen bìdere nen assignare.",
    "No tags found" : "Peruna eticheta agatada",
    "No files in here" : "Perunu archìviu",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Modified" : "Modificadu",
    "Tag name is empty" : "Su nùmene de s'eticheta est bòidu",
    "Select tag …" : "Seletziona eticheta ...",
    "Tagged files" : "Archìvios cun eticheta",
    "Select tags to filter by" : "Seletziona etichetas pro filtrare",
    "Please select tags to filter by" : "Seletziona etichetas pro filtrare",
    "No files found for the selected tags" : "Perunu archìviu agatadu pro is etichetas seletzionadas",
    "Create a new tag" : "Crea un'eticheta noa"
},
"nplurals=2; plural=(n != 1);");
